@@ -9,12 +9,12 @@ import time
 
 
 class SaagieApiManager:
-    def __init__(self, url_saagie, id_plateform, user, password):
+    def __init__(self, url_saagie, id_platform, user, password):
         """
         Initialize the class
         Doc Saagie URL example: https://saagie-manager.prod.saagie.io/api/doc
         :param url_saagie: platform URL (eg: https://saagie-manager.prod.saagie.io)
-        :param id_plateform: Platform Id (you can find in the URL when you are on your own
+        :param id_platform: Platform Id (you can find in the URL when you are on your own
         platform (eg, the id of the platform is 6: https://saagie-beta.prod.saagie.io/manager/platform/6/#/manager/6))
         :param user: username to login with
         :param password: password to login with
@@ -22,24 +22,24 @@ class SaagieApiManager:
         if not url_saagie.endswith('/'):
             url_saagie += '/'
         self.url_saagie = url_saagie
-        self.id_plateform = id_plateform
+        self.id_platform = id_platform
         self.suffix_api = 'api/v1/'
         self.auth = (user, password)
 
-    def get_plateforms_info(self):
+    def get_platforms_info(self):
         """
         Getting information on all installed platform (eg: id, datamart IP, datamart Port, Datalake IP etC..c)
         requests.models.Response :return: the platforms informations
         """
         return requests.get(self.url_saagie + self.suffix_api + 'platform', auth=self.auth, verify=False)
 
-    def get_plateform_info(self):
+    def get_platform_info(self):
         """
         Getting information on a platform (eg: id, datamart IP, datamart Port, Datalake IP etC..c)
         requests.models.Response: return: platform informations
         """
-        print(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform))
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform)
+        print(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform))
+        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform)
                             , auth=self.auth
                             , verify=False)
 
@@ -49,20 +49,20 @@ class SaagieApiManager:
         requests.models.Response: return: platform informations
         """
         return requests.get(
-            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/connectioninfo/impala'
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/connectioninfo/impala'
             , auth=self.auth
             , verify=False)
 
-    def get_plateform_env_vars(self):
+    def get_platform_env_vars(self):
         """
         Getting all environment variables available on the platform
         requests.models.Response: return: platform environment variables
         """
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/envvars'
+        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/envvars'
                             , auth=self.auth
                             , verify=False)
 
-    def create_plateform_env_vars(self, name_envvar, value_envvar, is_password=False):
+    def create_platform_env_vars(self, name_envvar, value_envvar, is_password=False):
         """
         Create an environment variable
         string: param name_envvar: name of the environment variable
@@ -78,21 +78,21 @@ class SaagieApiManager:
         payload = "{\"name\":\"" + str(name_envvar).upper() + '"' + \
                   ",\"value\":\"" + str(value_envvar) + '"' + \
                   ",\"isPassword\":" + the_password + \
-                  ",\"platformId\":\"" + str(self.id_plateform) + '"}'
+                  ",\"platformId\":\"" + str(self.id_platform) + '"}'
 
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/envvars',
+        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/envvars',
                              data=payload,
                              auth=self.auth,
                              verify=False)
 
-    def delete_plateform_env_vars(self, id_venv):
+    def delete_platform_env_vars(self, id_venv):
         """
-        Delete an environement variable environment variable
+        Delete an environment variable environment variable
         int or string: param id_venv: id of the environment variable
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/envvars/' \
+        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/envvars/'
                                + str(id_venv),
                                auth=self.auth,
                                verify=False)
@@ -104,7 +104,7 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job/'
+        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job/'
                              + str(job_id) + '/run',
                              auth=self.auth,
                              verify=False)
@@ -116,7 +116,7 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job/'
+        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job/'
                              + str(job_id) + '/stop',
                              auth=self.auth,
                              verify=False)
@@ -126,7 +126,7 @@ class SaagieApiManager:
         Get all the jobs on the platform
         requests.models.Response: return: platform jobs
         """
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job',
+        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job',
                             auth=self.auth,
                             verify=False)
 
@@ -136,9 +136,10 @@ class SaagieApiManager:
         int or string:param job_id:
         request.models.Response: return
         """
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job/' + str(job_id),
-                            auth=self.auth,
-                            verify=False)
+        return requests.get(
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job/' + str(job_id),
+            auth=self.auth,
+            verify=False)
 
     def modify_job_schedule(self, job_id, job):
         """
@@ -148,12 +149,13 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job/' + str(job_id),
-                            data=json.dumps(job),
-                            auth=self.auth,
-                            verify=False)
+        return requests.post(
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job/' + str(job_id),
+            data=json.dumps(job),
+            auth=self.auth,
+            verify=False)
 
-    def run_job_callback(self, job_id, freq, timeout = -1):
+    def run_job_callback(self, job_id, freq, timeout=-1):
         """
         Run a job and wait for the final status (KILLED, FAILED or SUCCESS)
         int or string:param job_id:
@@ -164,9 +166,8 @@ class SaagieApiManager:
         self.run_job(job_id)
         state = ''
         sec = 0
-        to = False
-
-        while(state != "STOPPED"):
+        res = None
+        while state != "STOPPED":
             to = False if timeout == -1 else sec >= timeout
             if to:
                 raise TimeoutError("Last state known : " + state)
@@ -176,7 +177,7 @@ class SaagieApiManager:
             state = json.loads(res.text)['last_state']['state']
             print('Current state : ' + state)
 
-        return json.loads(res.text)['last_state']['lastTaskStatus'] 
+        return json.loads(res.text)['last_state']['lastTaskStatus']
 
     def __upload_file(self, file):
         """
@@ -186,13 +187,13 @@ class SaagieApiManager:
         """
 
         response = requests.post(
-            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + "/job/upload",
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + "/job/upload",
             auth=self.auth,
             files={'file': open(file, 'rb')},
             verify=False)
 
         if response == -1:
-            raise NameError("An unexpected error occured, please raise a ticket to SAAGIE to solve the problem")
+            raise NameError("An unexpected error occurred, please raise a ticket to SAAGIE to solve the problem")
         else:
             return json.loads(response.text)['fileName']
 
@@ -211,9 +212,9 @@ class SaagieApiManager:
         """
 
         # Before creating a job you need to upload the file containing the code into SAAGIE
-        fileName = self.__upload_file(file)
+        file_name = self.__upload_file(file)
 
-        # if you want to create a spark job, you need to specifye the extra language
+        # if you want to create a spark job, you need to specify the extra language
         if capsule_code == 'spark':
             options = {
                 "language_version": str(language_version),
@@ -233,13 +234,13 @@ class SaagieApiManager:
             "memory": str(memory),
             "cpu": str(cpu),
             "disk": str(disk),
-            "file": str(fileName),
+            "file": str(file_name),
             "isInternalSubDomain": False,
             "isInternalPort": False
         }
 
         data = {
-            "platform_id": str(self.id_plateform),
+            "platform_id": str(self.id_platform),
             "capsule_code": str(capsule_code),
             "category": str(category),
             "current": current,
@@ -251,7 +252,7 @@ class SaagieApiManager:
         }
 
         # sending the request
-        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + "/job",
+        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + "/job",
                           data=json.dumps(data),
                           auth=self.auth,
                           verify=False
@@ -260,7 +261,7 @@ class SaagieApiManager:
         return r
 
     def update_job(self, job_id, file, capsule_code='python', template="python {file} arg1 arg2",
-                   release_note="", language_version='3.5.2', cpu=0.3, memory=512, disk=512, 
+                   release_note="", language_version='3.5.2', cpu=0.3, memory=512, disk=512,
                    extra_language='python', extra_version='3.5.2'):
         """
         Update a job
@@ -274,15 +275,16 @@ class SaagieApiManager:
         int or string: param memory: job's Memory
         int or string: param disk: job's disk space
         string: param extra_language: extra language if required (for spark jobs to select python or java/scala)
-        string: param extra_version: version of the extra language if required (for saprk jobs to select the version of python or java/scala)
+        string: param extra_version: version of the extra language if required (for spark jobs to select the
+                                      version of python or java/scala)
         requests.models.Response: return: status of the query (200, 204: OK, other: KO -> available with
         method return_variable.status_code)
         """
 
         # Before creating a job you need to upload the file containing the code into SAAGIE
-        fileName = self.__upload_file(file)
+        file_name = self.__upload_file(file)
 
-        # if you want to create a spark job, you need to specifye the extra language
+        # if you want to create a spark job, you need to specify the extra language
         if capsule_code == 'spark':
             options = {
                 "language_version": str(language_version),
@@ -302,7 +304,7 @@ class SaagieApiManager:
             "memory": str(memory),
             "cpu": str(cpu),
             "disk": str(disk),
-            "file": str(fileName),
+            "file": str(file_name),
             "isInternalSubDomain": False,
             "isInternalPort": False
         }
@@ -310,7 +312,8 @@ class SaagieApiManager:
         data = {"current": current}
 
         # sending the request
-        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + "/job/" + str(job_id) + "/version",
+        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + "/job/" + str(
+            job_id) + "/version",
                           data=json.dumps(data),
                           auth=self.auth,
                           verify=False
@@ -319,16 +322,15 @@ class SaagieApiManager:
         return r
 
     def create_pipeline(self, list_id_jobs, pipeline_name):
-        dict_workflow = {}
-        dict_workflow['name'] = pipeline_name
+        dict_workflow = {'name': pipeline_name}
         list_worklfow = []
         position_job_workflow = 0
-        for id in list_id_jobs:
-            list_worklfow.append({"id": int(id), "position": position_job_workflow})
+        for job_id in list_id_jobs:
+            list_worklfow.append({"id": int(job_id), "position": position_job_workflow})
             position_job_workflow += 1
         dict_workflow['jobs'] = list_worklfow
 
-        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + "/workflow",
+        r = requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + "/workflow",
                           data=json.dumps(dict_workflow),
                           auth=self.auth,
                           verify=False
@@ -342,7 +344,7 @@ class SaagieApiManager:
         :param pipeline_id: Id of the pipeline (int or str)
         :return:
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow/'
+        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow/'
                              + str(pipeline_id) + '/run',
                              auth=self.auth,
                              verify=False)
@@ -354,7 +356,7 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/job/' \
+        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/job/'
                                + str(id_job),
                                auth=self.auth,
                                verify=False)
@@ -366,7 +368,7 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow/' \
+        return requests.delete(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow/'
                                + str(id_pipeline),
                                auth=self.auth,
                                verify=False)
@@ -376,7 +378,7 @@ class SaagieApiManager:
         Get all the pipelines on the platform
         requests.models.Response: return: platform pipelines
         """
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow',
+        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow',
                             auth=self.auth,
                             verify=False)
 
@@ -386,9 +388,10 @@ class SaagieApiManager:
         int or string:param pipeline_id:
         request.models.Response: return
         """
-        return requests.get(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow/' + str(pipeline_id),
-                            auth=self.auth,
-                            verify=False)
+        return requests.get(
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow/' + str(pipeline_id),
+            auth=self.auth,
+            verify=False)
 
     def modify_pipeline_schedule(self, pipeline_id, pipeline):
         """
@@ -398,10 +401,11 @@ class SaagieApiManager:
         requests.models.Response: return: status of the query (200: OK, other: KO -> available with
         method return_variable.status_code)
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow/' + str(pipeline_id),
-                            data=json.dumps(pipeline),
-                            auth=self.auth,
-                            verify=False)
+        return requests.post(
+            self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow/' + str(pipeline_id),
+            data=json.dumps(pipeline),
+            auth=self.auth,
+            verify=False)
 
     def stop_pipeline(self, pipeline_id):
         """
@@ -410,7 +414,7 @@ class SaagieApiManager:
         :param pipeline_id: Id of the pipeline (int or str)
         :return:
         """
-        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_plateform) + '/workflow/'
+        return requests.post(self.url_saagie + self.suffix_api + 'platform/' + str(self.id_platform) + '/workflow/'
                              + str(pipeline_id) + '/stop',
                              auth=self.auth,
-                             verify=False)
\ No newline at end of file
+                             verify=False)
