@@ -70,6 +70,25 @@ gql_create_project_env_var = """
   }}
 """
 
+
+#   ____ _           _
+#  / ___| |_   _ ___| |_ ___ _ __
+# | |   | | | | / __| __/ _ \ '__|
+# | |___| | |_| \__ \ ||  __/ |
+#  \____|_|\__,_|___/\__\___|_|
+
+
+gql_get_cluster_info = """
+{
+  getClusterCapacity {
+    cpu
+    gpu
+    memory
+  }
+}
+"""
+
+
 #                                 _  _                 _
 #  _ __   ___  _ __    ___   ___ (_)| |_   ___   _ __ (_)  ___  ___
 # | '__| / _ \| '_ \  / _ \ / __|| || __| / _ \ | '__|| | / _ \/ __|
@@ -92,6 +111,13 @@ gql_get_repositories_info = """
   }
 """
 
+gql_get_runtimes = """{{technology(id: "{0}"){{
+  __typename 
+  ... on JobTechnology {{contexts{{label}}}}
+  ... on SparkTechnology {{contexts{{label}}}}
+  }}}}
+"""
+
 #                        _              _
 #  _ __   _ __   ___    (_)  ___   ___ | |_  ___
 # | '_ \ | '__| / _ \   | | / _ \ / __|| __|/ __|
@@ -321,17 +347,30 @@ gql_stop_job_instance = """
 
 gql_edit_job = """
   mutation{{
-    editJob(job: {0}) {{
+    editJob(job: {{
+      id: "{0}"
+      {1}
+    }}
+    ) {{
         id,
         name,
         description,
         isScheduled,
-        cronScheduling
+        cronScheduling,
+        scheduleTimezone
+        resources{{
+        cpu {{
+            request,
+            limit}},
+        memory{{
+            request,
+            limit}}
+        }}
       }}
   }}
 """
 
-gql_create_job = '{{"operationName": "createJobMutation",\
+gql_create_job = """{{"operationName": "createJobMutation",\
                    "variables": {{\
                        "job": {{\
                            "projectId": "{1}",\
@@ -340,27 +379,79 @@ gql_create_job = '{{"operationName": "createJobMutation",\
                            "category": "{3}",\
                            "technology": {{"id":"{4}"}},\
                            "isStreaming": false,\
-                           "isScheduled": false\
+                           {9}, \
+                           "resources": {10}, \
+                           "doesUseGPU": false\
                        }},\
                        "jobVersion": {{\
                            "runtimeVersion": "{5}",\
                            "commandLine": "{6}",\
                            {8}\
                            "dockerInfo": null,\
-                           "resources": {{\
-                               "cpu": 0.3,\
-                               "disk": 512,\
-                               "memory": 512\
-                           }},\
-                           "releaseNote": "{7}",\
-                           "doesUseGPU": false\
+                           "releaseNote": "{7}"\
                        }},\
                        "file":null\
                    }},\
                    "query": "mutation createJobMutation($job: JobInput!, $jobVersion: JobVersionInput!, $file: Upload) \
                    {{\\n  createJob(job: $job, jobVersion: $jobVersion, file: $file) \
                    {{\\n    id\\n    versions {{\\n      number\\n      __typename\\n    }}\\n   \
-                    __typename\\n  }}\\n}}\\n"}}'
+                    __typename\\n  }}\\n}}\\n"}}"""
+
+gql_upgrade_job = """{{"operationName": "addJobVersionMutation",\
+    "variables": {{\
+        "jobId": "{0}",\
+        "jobVersion": {{\
+            "runtimeVersion": "{1}",\
+            "commandLine": "{2}",\
+            {4}\
+            "dockerInfo": null,\
+            "releaseNote": "{3}"\
+        }},\
+        "file": null\
+    }},\
+    "query": "mutation addJobVersionMutation($jobId: UUID!, $jobVersion: JobVersionInput!, $file: Upload) \
+    {{\\n  addJobVersion(jobId: $jobId, jobVersion: $jobVersion, file: $file) \
+    {{\\n    number\\n    __typename\\n  }}\\n}}\\n"}}"""
+
+gql_get_info_job = """query {{
+  job(id:"{0}"){{
+    id,
+    name,
+    description,
+    creationDate,
+    isScheduled,
+    cronScheduling,
+    scheduleStatus,
+    scheduleTimezone,
+    isStreaming,
+    isDeletable,
+    graphPipelines(isCurrent: true){{
+      id
+    }},
+    category,
+    technology{{
+      id
+    }},
+    alerting{{
+      emails,
+      statusList,
+      loginEmails{{
+        email
+      }}
+    }},
+    resources{{
+      cpu{{
+        request,
+        limit
+      }}
+      memory{{
+        request,
+        limit
+      }}
+    }}
+  }}
+}}
+"""
 
 gql_extra_technology = '"extraTechnology": {{\
                            "language": "{0}",\
@@ -487,37 +578,40 @@ gql_get_project_app = """
 
 gql_get_pipelines = """
   query{{
-    pipelines(projectId: "{0}"){{
-      id,
-      name,
-      description,
-      alerting{{
-        emails,
-        loginEmails{{
-          login,
-          email
-        }},
-        statusList
-      }},
-      pipelineInstanceCount,
-      instances{1}{{
+    project(id: "{0}"){{
+      pipelines{{
         id,
-        status,
-        startTime,
-        endTime
-      }},
-      creationDate,
-      creator,
-      isScheduled,
-      cronScheduling,
-      scheduleStatus
-    }}
-  }}
+        name,
+        description,
+        alerting{{
+          emails,
+          loginEmails{{
+            login,
+            email
+          }},
+          statusList
+        }},
+        pipelineInstanceCount,
+        instances{1}{{
+          id,
+          status,
+          startTime,
+          endTime
+        }},
+        creationDate,
+        creator,
+        isScheduled,
+        cronScheduling,
+        scheduleStatus,
+        scheduleTimezone,
+        isLegacyPipeline
+      }}
+  }}}}
   """
 
 gql_get_pipeline = """
   query{{
-    pipeline(id: "{0}"){{
+    graphPipeline(id: "{0}"){{
       id,
       name,
       description,
@@ -534,7 +628,9 @@ gql_get_pipeline = """
       creator,
       isScheduled,
       cronScheduling,
-      scheduleStatus
+      scheduleStatus,
+      scheduleTimezone,
+      isLegacyPipeline
     }}
   }}
   """
@@ -553,15 +649,33 @@ gql_stop_pipeline_instance = """
   """
 
 gql_edit_pipeline = """
-  mutation{{
-    editPipeline(pipeline: {0}) {{
-        id,
-        name,
-        description,
-        isScheduled,
-        cronScheduling
-      }}
-  }}
+  mutation($id: UUID!, $name: String, $description: String, $emails: [Email!], $statusList: [InstanceStatus!]!,
+          $isScheduled: Boolean, $cronScheduling: Cron, $scheduleTimezone:TimeZone)  {
+    editPipeline(pipeline: {
+        id: $id,
+        name: $name,
+        description: $description,
+        alerting: {
+          emails: $emails,
+          statusList: $statusList
+        }
+        isScheduled: $isScheduled,
+        cronScheduling: $cronScheduling,
+        scheduleTimezone: $scheduleTimezone
+      })
+    {
+      id,
+      name,
+      description,
+      alerting{
+        emails,
+        statusList
+      }
+      isScheduled,
+      cronScheduling,
+      scheduleTimezone
+    }
+  }
 """
 
 gql_run_pipeline = """
@@ -595,3 +709,58 @@ gql_get_pipeline_instance = """
       }}
   }}
 """
+
+gql_create_graph_pipeline = """
+  mutation($jobNodes: [JobNodeInput!], $conditionNodes: [ConditionNodeInput!]) {{
+  createGraphPipeline(pipeline:  {{
+    name: "{0}",
+    description: "{1}",
+    projectId: "{2}",
+    releaseNote : "{3}",
+    {4}
+    graph: {{jobNodes: $jobNodes,
+                conditionNodes: $conditionNodes}}
+    }}
+  ) {{
+    id
+  }}
+}}
+"""
+
+gql_delete_pipeline = """
+  mutation {{
+  deletePipeline (
+    id: "{0}"
+  )
+}}
+"""
+
+gql_upgrade_pipeline = """
+  mutation($id: UUID!, $jobNodes: [JobNodeInput!], $conditionNodes: [ConditionNodeInput!], $releaseNote: String){
+  addGraphPipelineVersion(
+    pipelineId: $id,
+    graph: {jobNodes: $jobNodes,
+                conditionNodes: $conditionNodes},
+    releaseNote: $releaseNote
+    )
+    {
+      number,
+      releaseNote,
+      graph{
+        jobNodes {
+          id,
+          job {
+            id
+          }
+        },
+        conditionNodes{
+          id
+        }
+      },
+      creationDate,
+      creator,
+      isCurrent,
+      isMajor
+    }
+  }
+"""
\ No newline at end of file
