@@ -4,9 +4,12 @@ Projects & Jobs - to interact with the manager API, see the manager subpackage)
 
 """
 import json
+import logging
 import time
 import re
+import pytz
 from pathlib import Path
+from croniter import croniter
 
 from gql import gql
 from gql import Client
@@ -14,6 +17,7 @@ from gql.transport.requests import RequestsHTTPTransport
 
 from .auth import *
 from .gql_template import *
+from .graph_pipeline import *
 
 
 class SaagieApi:
@@ -49,6 +53,7 @@ class SaagieApi:
                                self.id_platform, self.login, self.password)
         url = self.url_saagie + self.suffix_api + 'platform/'
         url += str(self.id_platform) + '/graphql'
+        self._url = url
         self._transport = RequestsHTTPTransport(
             url=url,
             auth=self.auth,
@@ -261,6 +266,16 @@ class SaagieApi:
         query = gql(gql_delete_env_var.format(project_env_id))
         return self.client.execute(query)
 
+    # ##########################################################
+    # ###                    cluster                        ####
+    # ##########################################################
+
+    def get_cluster_capacity(self):
+        """Get information for cluster (cpu, gpu, memory)
+        """
+        query = gql(gql_get_cluster_info)
+        return self.client_gateway.execute(query)
+
     # ##########################################################
     # ###                    repositories                   ####
     # ##########################################################
@@ -273,6 +288,27 @@ class SaagieApi:
         query = gql(gql_get_repositories_info)
         return self.client_gateway.execute(query)
 
+    # ##########################################################
+    # ###                    technologies                   ####
+    # ##########################################################
+
+    def get_runtimes(self, technology_id):
+        """Get the list of runtimes for a technology id
+
+        Parameters
+        ----------
+        technology_id : str
+            UUID of the technology
+
+        Returns
+        -------
+        dict
+            Dict of runtime labels
+
+        """
+        query = gql_get_runtimes.format(technology_id)
+        return self.client_gateway.execute(gql(query))
+
     # ######################################################
     # ###                    projects                   ####
     # ######################################################
@@ -542,23 +578,62 @@ class SaagieApi:
         query = gql(gql_stop_job_instance.format(job_instance_id))
         return self.client.execute(query)
 
-    # TO DETAIL!
-    # Detail job dict parameter, or explode the number of parameters to have
-    # a more comprehensible method
-    def edit_job(self, job):
+    def edit_job(self, job_id, job_name=None, description=None, is_scheduled=False,
+                 cron_scheduling=None, schedule_timezone="UTC", resources=None):
         """Edit a job
 
         Parameters
         ----------
-        job : TYPE
-            Job
+        job_id : str
+            UUID of your job (see README on how to find it)
+        job_name : str, optional
+            Seconds to wait between two state checks
+        description : str, optional
+            Description of job
+        is_scheduled : bool, optional
+            True if the job is scheduled, else False
+        cron_scheduling : str, optional
+            Scheduling cron format
+        schedule_timezone : str, optional
+            Timezone of the scheduling
+        resources : dict, optional
+            CPU, memory limit and requests
+            Example: {"cpu":{"request":0.5, "limit":2.6},"memory":{"request":1.0}}
 
         Returns
         -------
         dict
             Dict of job information
         """
-        query = gql(gql_edit_job.format(job))
+        gql_payload = []
+        if job_name:
+            gql_payload.append(f'name: "{job_name}"')
+
+        if description:
+            gql_payload.append(f'description: "{description}"')
+
+        if is_scheduled:
+            gql_payload.append(f'isScheduled: true')
+
+            if cron_scheduling and croniter.is_valid(cron_scheduling):
+                gql_payload.append(f'cronScheduling: "{cron_scheduling}"')
+            else:
+                raise RuntimeError(f"{cron_scheduling} is not valid cron format")
+
+            if schedule_timezone in list(pytz.all_timezones):
+                gql_payload.append(f'scheduleTimezone: "{schedule_timezone}"')
+            else:
+                raise RuntimeError("Please specify a correct timezone")
+
+        else:
+            gql_payload.append(f'isScheduled: false')
+
+        if resources:
+            resources_str = json.dumps(resources).replace("\"", "")
+            gql_payload.append(f'resources: {resources_str}')
+
+        gql_payload_str = ", ".join(gql_payload)
+        query = gql(gql_edit_job.format(job_id, gql_payload_str))
         return self.client.execute(query)
 
     def create_job(self, job_name, project_id, file=None, description='',
@@ -566,7 +641,8 @@ class SaagieApi:
                    technology_catalog='Saagie',
                    runtime_version='3.6',
                    command_line='python {file} arg1 arg2', release_note='',
-                   extra_technology='', extra_technology_version=''):
+                   extra_technology='', extra_technology_version='',
+                   cron_scheduling=None, schedule_timezone="UTC", resources=None):
         """Create job in given project
 
         NOTE
@@ -611,6 +687,13 @@ class SaagieApi:
         extra_technology_version : str, optional
             Version of the extra technology. Leave to empty string when not
             needed
+        cron_scheduling : str, optional
+            Scheduling CRON format
+        schedule_timezone : str, optional
+            Timezone of the scheduling
+        resources : dict, optional
+            CPU, memory limit and requests
+            Example: {"cpu":{"request":0.5, "limit":2.6},"memory":{"request":1.0}}
 
         Returns
         -------
@@ -622,7 +705,6 @@ class SaagieApi:
         requests.exceptions.RequestException
             When requests fails
         """
-        file = Path(file)
 
         technologies_for_project = self.get_project_technologies(project_id)['technologiesByCategory']
         technologies_for_project_and_category = [
@@ -662,52 +744,184 @@ class SaagieApi:
         else:
             extra_tech = ''
 
-        url = self.url_saagie + self.suffix_api + 'platform/'
-        url += str(self.id_platform) + "/graphql"
+        if resources is None:
+            resources = {}
+        gql_scheduling_payload = []
 
+        if cron_scheduling:
+            gql_scheduling_payload.append(f'"isScheduled": true')
+
+            if croniter.is_valid(cron_scheduling):
+                gql_scheduling_payload.append(f'"cronScheduling": "{cron_scheduling}"')
+            else:
+                raise RuntimeError(f"{cron_scheduling} is not valid cron format")
+
+            if schedule_timezone in list(pytz.all_timezones):
+                gql_scheduling_payload.append(f'"scheduleTimezone": "{schedule_timezone}"')
+            else:
+                raise RuntimeError("Please specify a correct timezone")
+
+        else:
+            gql_scheduling_payload.append(f'"isScheduled": false')
+
+        gql_scheduling_payload_str = ", ".join(gql_scheduling_payload)
+        resources_str = json.dumps(resources)
+        payload_str = gql_create_job.format(job_name,
+                                            project_id,
+                                            description,
+                                            category,
+                                            technology_id,
+                                            runtime_version,
+                                            command_line,
+                                            release_note,
+                                            extra_tech,
+                                            gql_scheduling_payload_str,
+                                            resources_str)
+
+        return self.__launch_request(file, payload_str)
+
+    def get_job_info(self, job_id):
+        """Get job's info
+
+        Parameters
+        ----------
+        job_id : str
+            UUID of your job
+
+        Returns
+        -------
+        dict
+            Dict of job's info
+
+        """
+        query = gql_get_info_job.format(job_id)
+        return self.client.execute(gql(query))
+        
+    def upgrade_job(self, job_id, file=None, use_previous_artifact=False, runtime_version='3.6',
+                   command_line='python {file} arg1 arg2', release_note=None):
+        """Ugrade a job
+
+        Parameters
+        ----------
+        job_id : str
+            UUID of your job
+        file: str (optional)
+            Path to your file
+        use_previous_artifact: bool (optional)
+            Use previous artifact
+        runtime_version: str (optional)
+            Runtime version
+        command_line: str (optional)
+            Command line
+        release_note: str (optional)
+            Release note
+
+        Returns
+        -------
+        dict
+            Dict with version number
+
+        """
+
+        # Verify if specified runtime exists
+        technology_id = self.get_job_info(job_id)["job"]["technology"]["id"]
+        available_runtimes = [c["label"] for c in self.get_runtimes(technology_id)["technology"]["contexts"]]
+        if runtime_version not in available_runtimes:
+            raise RuntimeError(f"Specified runtime does not exist ({runtime_version}). Available runtimes : {','.join(available_runtimes)}.")
+
+        if file and use_previous_artifact:
+            logging.warn("You can not specify a file and use the previous artifact. By default, the specified file will be used.")
+        use_previous_artifact_str = f'"usePreviousArtifact": {"null" if use_previous_artifact else "false"},'
+
+        payload_str = gql_upgrade_job.format(job_id, runtime_version, command_line, release_note, use_previous_artifact_str)
+
+        return self.__launch_request(file, payload_str)
+
+    def __launch_request(self, file, payload_str):
         if file:
             file = Path(file)
-            # logging.debug("Creating jobs with archive ...")
             with file.open(mode='rb') as f:
                 files = {
                     '1': (file.name, f),
-                    'operations': (None, gql_create_job.format(job_name,
-                                                               project_id,
-                                                               description,
-                                                               category,
-                                                               technology_id,
-                                                               runtime_version,
-                                                               command_line,
-                                                               release_note,
-                                                               extra_tech)),
+                    'operations': (None, payload_str),
                     'map': (None, '{ "1": ["variables.file"] }'),
                 }
-                response = requests.post(url,
+                response = requests.post(self._url,
                                          files=files,
                                          auth=self.auth,
                                          verify=False)
         else:
-            payload_str = gql_create_job.format(job_name,
-                                                project_id,
-                                                description,
-                                                category,
-                                                technology_id,
-                                                runtime_version,
-                                                command_line,
-                                                release_note,
-                                                extra_tech)
             payload = json.loads(payload_str)
-            response = requests.post(url,
+            response = requests.post(self._url,
                                      json=payload,
                                      auth=self.auth,
                                      verify=False)
-
+        
         if response:
             return json.loads(response.content)
         else:
             m = f"Requests failed with status_code :'{response.status_code}'"
             raise requests.exceptions.RequestException(m)
 
+    def get_job_id(self, job_name, project_name):
+        """Get the job id with the job name and project name
+
+        Parameters
+        ----------
+        job_name : str
+            Name of your job
+        project_name : str
+            Name of your project
+
+        Returns
+        -------
+        dict
+            Job UUID
+
+        """
+        projects = self.get_projects_info()["projects"]
+        project = list(filter(lambda p: p["name"] == project_name, projects))
+        if project:
+            project_id = project[0]["id"]
+            jobs = self.get_project_jobs(project_id, instances_limit=1)["jobs"]
+            job = list(filter(lambda j: j["name"] == job_name, jobs))
+            if job:
+                return job[0]["id"]
+            else:
+                raise NameError(f"Job {job_name} does not exist.")
+        else:
+            raise NameError(f"Project {project_name} does not exist or you don't have permission to see it.")
+    
+    def upgrade_job_by_name(self, job_name, project_name, file=None, use_previous_artifact=False, runtime_version='3.6',
+                   command_line='python {file} arg1 arg2', release_note=None):
+        """Ugrade a job
+
+        Parameters
+        ----------
+        job_name : str
+            Name of your job
+        project_name : str
+            Name of your project
+        file: str (optional)
+            Path to your file
+        use_previous_artifact: bool (optional)
+            Use previous artifact
+        runtime_version: str (optional)
+            Runtime version
+        command_line: str (optional)
+            Command line
+        release_note: str (optional)
+            Release note
+
+        Returns
+        -------
+        dict
+            Dict with version number
+
+        """
+        job_id = self.get_job_id(job_name, project_name)
+        return self.upgrade_job(job_id, file, use_previous_artifact, runtime_version, command_line, release_note)
+
     def delete_job(self, job_id):
         """Delete a given job
 
@@ -858,23 +1072,39 @@ class SaagieApi:
     # TO DETAIL!
     # Detail pipeline dict parameters, or explode the number of parameters to
     # have a more comprehensible method
-    def edit_pipeline(self, pipeline_id):
+    def edit_pipeline(self, pipeline_id, name=None, description=None, emails=None, status_list=None, is_scheduled=None,
+             cron_scheduling=None, schedule_timezone=None):
         """Edit a given pipeline
         NB : You can only edit pipeline if you have at least the editor role on
         the project
 
-        Parameters
-        ----------
-        pipeline_id : str
-            UUID of your pipeline  (see README on how to find it)
+        Args:
+            pipeline_id (str): mandatory pipeline id to edit
+            name (str): if not filled, defaults to current value
+            description (str): if not filled, defaults to current value
+            emails (list, optional): if not filled, defaults to current value
+            status_list (list, optional): if not filled, defaults to current value
+            is_scheduled (bool, optional): if not filled, defaults to current value
+            cron_scheduling (str, optional): if not filled, defaults to current value
+            schedule_timezone (str, optional): if not filled, defaults to current value
 
-        Returns
-        -------
-        dict
-            Dict of pipeline information
+        Returns:
+            [type]: [description]
         """
-        query = gql(gql_edit_pipeline.format(pipeline_id))
-        return self.client.execute(query)
+        pipeline_info = self.get_project_pipeline(pipeline_id)
+        if not name: name = pipeline_info["graphPipeline"]["name"]
+        if not description: description = pipeline_info["graphPipeline"]["description"]
+        if not emails: emails = pipeline_info["graphPipeline"]["alerting"]["emails"]
+        if not status_list: status_list = pipeline_info["graphPipeline"]["alerting"]["statusList"]
+        if not is_scheduled: is_scheduled = pipeline_info["graphPipeline"]["isScheduled"]
+        if not cron_scheduling: cron_scheduling = pipeline_info["graphPipeline"]["cronScheduling"]
+        if not schedule_timezone: schedule_timezone = pipeline_info["graphPipeline"]["scheduleTimezone"]
+
+        params = {'id': pipeline_id, 'name': name, 'description': description, 'emails': emails, 'statusList': status_list,
+                'isScheduled': is_scheduled, 'cronScheduling': cron_scheduling, 'scheduleTimezone': schedule_timezone}
+
+        query = gql(gql_edit_pipeline)
+        return self.client.execute(query, variable_values=params)
 
     def run_pipeline(self, pipeline_id):
         """Run a given pipeline
@@ -983,3 +1213,129 @@ class SaagieApi:
         """
         query = gql(gql_get_pipeline_instance.format(pipeline_instance_id))
         return self.client.execute(query)
+
+    def create_graph_pipeline(self, name, project_id, graph_pipeline, description="", release_note="",
+                              cron_scheduling=None, schedule_timezone="UTC"):
+        """
+        Create a pipeline in a given project
+
+        Parameters
+        ----------
+        name : str
+            Name of the pipeline. Must not already exist in the project
+        project_id : str
+            UUID of your project (see README on how to find it)
+        graph_pipeline : GraphPipeline
+
+        description : str, optional
+            Description of the pipeline
+        release_note: str, optional
+            Release note of the pipeline
+        cron_scheduling : str, optional
+            Scheduling CRON format
+        schedule_timezone : str, optional
+            Timezone of the scheduling
+
+        Returns
+        -------
+        dict
+            Dict of pipeline information
+        """
+        gql_scheduling_payload = []
+        if not graph_pipeline.list_job_nodes:
+            graph_pipeline.to_pipeline_graph_input()
+        if cron_scheduling:
+            gql_scheduling_payload.append(f'isScheduled: true')
+
+            if croniter.is_valid(cron_scheduling):
+                gql_scheduling_payload.append(f'cronScheduling: "{cron_scheduling}"')
+            else:
+                raise RuntimeError(f"{cron_scheduling} is not valid cron format")
+
+            if schedule_timezone in list(pytz.all_timezones):
+                gql_scheduling_payload.append(f'scheduleTimezone: "{schedule_timezone}"')
+            else:
+                raise RuntimeError("Please specify a correct timezone")
+
+        else:
+            gql_scheduling_payload.append(f'isScheduled: false')
+
+        gql_scheduling_payload_str = ", ".join(gql_scheduling_payload)
+
+        query_str = gql_create_graph_pipeline.format(
+            name,
+            description,
+            project_id,
+            release_note,
+            gql_scheduling_payload_str
+        )
+        params = {'jobNodes': graph_pipeline.list_job_nodes, 'conditionNodes': graph_pipeline.list_conditions_nodes}
+
+        query = gql(query_str)
+        return self.client.execute(query, variable_values=params)
+
+    def delete_pipeline(self, pipeline_id):
+        """Delete a pipeline given pipeline id
+
+        Parameters
+        ----------
+        pipeline_id : str
+            Pipeline id
+
+        Returns
+        -------
+        dict
+            Dict containing status of deletion
+        """
+        query = gql(gql_delete_pipeline.format(pipeline_id))
+
+        return self.client.execute(query)
+
+    def upgrade_pipeline(self, pipeline_id, graph_pipeline, release_note=""):
+        """
+        Create a pipeline in a given project
+
+        Parameters
+        ----------
+        pipeline_id: str, ID of pipeline
+        graph_pipeline : GraphPipeline
+        release_note: str, optional
+            Release note of the pipeline
+
+        Returns
+        -------
+        dict
+            Dict of pipeline information
+        """
+        if not graph_pipeline.list_job_nodes:
+            graph_pipeline.to_pipeline_graph_input()
+
+        params = {'id': pipeline_id, 'jobNodes': graph_pipeline.list_job_nodes, 'conditionNodes': graph_pipeline.list_conditions_nodes, 'releaseNote': release_note}
+
+        return self.client.execute(gql(gql_upgrade_pipeline), variable_values=params)
+
+    def get_pipeline_id(self, pipeline_name, project_name):
+        """Get the pipeline id with the pipeline name and project name
+        Parameters
+        ----------
+        pipeline_name : str
+            Name of your pipeline
+        project_name : str
+            Name of your project
+        Returns
+        -------
+        dict
+            Pipeline UUID
+        """
+        projects = self.get_projects_info()["projects"]
+        project = list(filter(lambda p: p["name"] == project_name, projects))
+        if project:
+            project_id = project[0]["id"]
+            pipelines = self.get_project_pipelines(project_id, instances_limit=1)["project"]["pipelines"]
+            pipeline = list(filter(lambda j: j["name"] == pipeline_name, pipelines))
+            if pipeline:
+                return pipeline[0]["id"]
+            else:
+                raise NameError(f"pipeline {pipeline_name} does not exist.")
+        else:
+            raise NameError(f"Project {project_name} does not exist or you don't have permission to see it.")
